from eda_cho.cli import group_by_count
import pandas as pd

def test_search_exception():
    row_count = 13
    df = group_by_count(keyword="자유", ascend=True, rowsize=row_count)
    
    # assert
    assert isinstance(df, pd.DataFrame)
    assert len(df) < row_count

def test_정열_및_행수제한():
    # given
    row_count = 3
    is_asc = True

    # when
    df = group_by_count(keyword="자유", ascend=is_asc, rowsize=row_count)
    
    # then
    assert isinstance(df, pd.DataFrame)
    assert df.iloc[0]["president"] == "윤보선"
    assert len(df) == row_count



from president_speech.db.parquet_interpreter import get_parquet_full_path
import pandas as pd
import typer

def group_by_count(keyword: str, ascend: bool=False, rowsize: int=12)-> pd.DataFrame:
    data_path = get_parquet_full_path()
    df = pd.read_parquet(data_path)
    f_df = df[df['speech_text'].str.contains(keyword, case=False)]
    rdf = f_df.groupby("president").size().reset_index(name='count')
    sdf = rdf.sort_values(by='count', ascending=ascend).reset_index(drop=True)
    if(rowsize <= 0):
        sdf = sdf
    elif(rowsize > len(sdf)):
        sdf = sdf
    else:
        sdf = sdf[0:(rowsize)]
    return sdf

def print_group_by_count(keyword: str, ascend: bool=False, rowsize: int=12):
    df = group_by_count(keyword, ascend, rowsize)
    print(df.to_string(index=False))

def entry_point():
    typer.run(print_group_by_count)

